class BaseComponent:
    @staticmethod
    def boom() -> None:
        print("👾💥👾👾👾💥")
